pub struct FilterConfig {
pub filter_type: FilterType,
pub cutoff: f64,
pub q: f64,
pub sample_rate: f64,
pub gain: Option<f64>,
}Expand description
Configuration parameters for a filter.
- For most filters,
gainis ignored. - For a Peak filter, a non-zero gain in dB is required.
Fields
filter_type: FilterTypecutoff: f64q: f64sample_rate: f64gain: Option<f64>Implementations
Sourceimpl FilterConfig
impl FilterConfig
Sourcepub fn new(
filter_type: FilterType,
cutoff: f64,
q: f64,
sample_rate: f64,
gain: Option<f64>,
) -> Result<Self, EEGError>
pub fn new( filter_type: FilterType, cutoff: f64, q: f64, sample_rate: f64, gain: Option<f64>, ) -> Result<Self, EEGError>
Creates a new FilterConfig.
Errors
- Returns an error if the sampling rate or Q factor are not positive.
- Returns an error if the cutoff frequency is not below the Nyquist limit.
- For Peak filters, returns an error if gain is not provided.